# Code of Conduct

## Our Pledge

We are committed to making participation in this project a harassment-free experience for everyone, regardless of age, body size, disability, ethnicity, sex characteristics, gender identity and expression, level of experience, education, socio-economic status, nationality, personal appearance, race, religion, or sexual identity and orientation.

## Our Standards

Examples of behavior that contributes to a positive environment:

- Being respectful and constructive in communication.
- Accepting feedback gracefully.
- Focusing on what is best for the community.

Examples of unacceptable behavior:

- Harassment, intimidation, or discriminatory language.
- Personal attacks, trolling, or insulting comments.
- Publishing others' private information without consent.

## Enforcement Responsibilities

Project maintainers are responsible for clarifying and enforcing acceptable behavior and may remove, edit, or reject comments, commits, code, issues, and other contributions that are not aligned with this Code of Conduct.

## Scope

This Code of Conduct applies within all project spaces and in public spaces when an individual is representing the project.

## Reporting

Report incidents to the maintainers through the repository's private channels (for example, private maintainer contact or security reporting path). All reports will be reviewed and investigated promptly and fairly.

## Enforcement

Maintainers may take corrective action, including warnings, temporary bans, or permanent bans for behavior deemed inappropriate.

## Attribution

This policy is adapted from the [Contributor Covenant](https://www.contributor-covenant.org/), version 2.1.
